// device.view.tsx
import { faCircleInfo, faServer, faSliders } from '@fortawesome/free-solid-svg-icons'
import { useAppSelector } from '@hooks'
import { GridLayout } from '@layout/grid.layout/grid.layout'
import { GridBox } from '@shared/components/box/gridBox.view'
import { JsonViewer } from '@shared/components/json_viewer/view/json_viewer.view'
import { useRef } from 'react'
import { Col, Row } from 'react-bootstrap'
import { useTranslation } from 'react-i18next'
import { useDeviceViewModel } from '../view_model/device.viewmodel'
import { DeviceList } from './boxes/devices.box.view'
import { DeviceListCollapsable } from './boxes/information.box.view'
import './device.scss'

const DeviceView = () => {
    const { t } = useTranslation('common')
    const searchRef = useRef<HTMLInputElement>(null)
    const { jsonYang } = useDeviceViewModel()
    const { selected } = useAppSelector(root => root.device)

    return (
        <GridLayout>
            <>
                <div key="device-list">
                    <GridBox title={t('device.box.list.title')} title_icon={faServer}>
                        <DeviceList searchRef={searchRef} />
                    </GridBox>
                </div>

                <div key="device-metadata">
                    <GridBox
                        title={t('device.box.information.title')}
                        title_icon={faCircleInfo}
                        disabled={!selected?.device}>
                        <Row>
                            <Col xs={12}>
                                <DeviceListCollapsable search={searchRef.current?.value || ''} />
                            </Col>
                        </Row>
                    </GridBox>
                </div>

                <div key="device-details">
                    <GridBox
                        title={t('device.box.configuration.title')}
                        title_icon={faSliders}
                        disabled={!selected?.device}>
                        <Row>
                            <Col xs={12}>{jsonYang && <JsonViewer json={jsonYang} />}</Col>
                        </Row>
                    </GridBox>
                </div>
            </>
        </GridLayout>
    )
}

export default DeviceView
