import { isRejectedWithValue } from '@reduxjs/toolkit'
import { setToken } from '@shared/reducer/user.reducer'
import { toast } from 'react-toastify'
import { Middleware, MiddlewareAPI } from 'redux'

/**
 * Log a warning and show a toast!
 */
export const rtkQueryErrorLogger: Middleware = (api: MiddlewareAPI) => (next) => (action) => {
    if (!isRejectedWithValue(action)) {
        return next(action)
    }

    const errorCode = action.payload.status || -1
    switch (errorCode) {
        case 403:
        case 401:
            api.dispatch(setToken(null))
            toast.info('Your session has expired. Please login again', {})
            break
        default:
            console.warn('An unkown error code returned: ' + errorCode)
    }

    return next(action)
}
